{% extends "base/exception.html" %}

{% block error_title %}Unauthorized{% endblock %}

{% block error_illustration %}
<div class="column">
  <span>4</span>
</div>
<div class="column">
  <img src="{{ url_for('base.static', filename='images/smileybones.svg') }}" alt="0" />
</div>
<div class="column">
  <span>1</span>
</div>
{% endblock %}
